==> blancoCsv-1.1.4-src.zip: src/blanco/csv/expand/BlancoCsvExpandRecord.java <==
/*
 * blancoCsv Copyright (C) 2005 Tosiki Iga
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 */
package blanco.csv.expand;

import java.io.File;
import java.io.IOException;

import javax.xml.transform.TransformerException;

import blanco.commons.util.BlancoNameAdjuster;
import blanco.csv.valueobject.BlancoCsvFieldStructure;
import blanco.csv.valueobject.BlancoCsvStructure;
import blanco.valueobject.BlancoValueObjectXml2JavaClass;
import blanco.valueobject.valueobject.BlancoValueObjectClassStructure;
import blanco.valueobject.valueobject.BlancoValueObjectFieldStructure;

public class BlancoCsvExpandRecord {
    /**
     * R[hWJ܂B
     * 
     * @param processStructure
     * @param direcotryValueObjectWork
     * @param directoryTarget
     * @param isGenerateJUnit
     * @throws IOException
     * @throws TransformerException
     */
    public static void expand(final BlancoCsvStructure processStructure,
            final File direcotryValueObjectWork, final File directoryTarget)
            throws IOException, TransformerException {
        final String className = BlancoNameAdjuster
                .toClassName(processStructure.getFileDefinitionId())
                + "CsvRecord";
        final String packageName = processStructure.getPackageName()
                + ".record";

        final BlancoValueObjectClassStructure voClass = new BlancoValueObjectClassStructure();
        voClass.setName(className);
        voClass.setPackage(packageName);
        voClass.setDescription("blancoCsvt@C`쐬ꂽR[hNX\nt@C`["
                + processStructure.getFileDefinitionId()
                + (processStructure.getFileDescription() == null ? "" : "/"
                        + processStructure.getFileDescription())
                + "]̃R[hNX\n");

        for (int indexField = 0; indexField < processStructure.getFieldList()
                .size(); indexField++) {
            final BlancoCsvFieldStructure field = (BlancoCsvFieldStructure) processStructure
                    .getFieldList().get(indexField);

            boolean isQuoted = false;
            String actualType = field.getType();
            if (field.getType().endsWith("(quote)")) {
                // NI[gw肪ꍇɂ́A^̂(quote)܂B
                actualType = field.getType().substring(0,
                        field.getType().length() - "(quote)".length());
                isQuoted = true;
            }
            if (field.getRequired() == false) {
                // Kvɉăbp[^ɑΉ܂B
                if (actualType.equals("int")) {
                    actualType = "java.lang.Integer";
                } else if (actualType.equals("long")) {
                    actualType = "java.lang.Long";
                }
            }

            BlancoValueObjectFieldStructure voField = new BlancoValueObjectFieldStructure();
            voClass.getFieldList().add(voField);

            if (field.getNo() != null) {
                voField.setNo(field.getNo());
            }

            voField.setName(field.getName());
            voField.setType(actualType);

            StringBuffer strbuf = new StringBuffer();
            if (field.getNo() != null) {
                strbuf.append("ڔԍ: " + field.getNo() + "\n");
            }
            if (field.getDescription() != null) {
                strbuf.append("ڂ̐: " + field.getDescription() + "\n");
            }
            if (isQuoted) {
                strbuf.append("̓_uNI[gēo͂܂B\n");
            }

            if (field.getMinLength() != null) {
                strbuf.append("MIN: " + field.getMinLength() + "\n");
            }
            if (field.getMaxLength() != null) {
                strbuf.append("MAX: " + field.getMaxLength() + "\n");
            }
            if (field.getRequired()) {
                strbuf.append("K{\n");
            }
            voField.setDescription(strbuf.toString());

            if (field.getDefault() != null) {
                voField.setDefault(field.getDefault());
            }
        }

        new BlancoValueObjectXml2JavaClass().structure2Source(voClass,
                directoryTarget);
    }
}

==> blancoCsv-1.2.1-src.zip: src/blanco/csv/expand/BlancoCsvExpandRecord.java <==
/*
 * blancoCsv Copyright (C) 2005 Tosiki Iga
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 */
package blanco.csv.expand;

import java.io.File;
import java.io.IOException;

import javax.xml.transform.TransformerException;

import blanco.commons.util.BlancoNameAdjuster;
import blanco.csv.valueobject.BlancoCsvFieldStructure;
import blanco.csv.valueobject.BlancoCsvStructure;
import blanco.valueobject.BlancoValueObjectXml2JavaClass;
import blanco.valueobject.valueobject.BlancoValueObjectClassStructure;
import blanco.valueobject.valueobject.BlancoValueObjectFieldStructure;

public class BlancoCsvExpandRecord {
    /**
     * \[Xt@C̕GR[fBOB
     */
    private String fEncoding = null;

    public void setEncoding(final String argEncoding) {
        fEncoding = argEncoding;
    }

    /**
     * R[hWJ܂B
     * 
     * @param processStructure
     * @param direcotryValueObjectWork
     * @param directoryTarget
     * @throws IOException
     * @throws TransformerException
     */
    public void expand(final BlancoCsvStructure processStructure,
            final File direcotryValueObjectWork, final File directoryTarget)
            throws IOException, TransformerException {
        final String className = BlancoNameAdjuster
                .toClassName(processStructure.getFileDefinitionId())
                + "CsvRecord";
        final String packageName = processStructure.getPackageName()
                + ".record";

        final BlancoValueObjectClassStructure voClass = new BlancoValueObjectClassStructure();
        voClass.setName(className);
        voClass.setPackage(packageName);
        voClass.setDescription("blancoCsvt@C`쐬ꂽR[hNX\nt@C`["
                + processStructure.getFileDefinitionId()
                + (processStructure.getFileDescription() == null ? "" : "/"
                        + processStructure.getFileDescription())
                + "]̃R[hNX\n");

        for (int indexField = 0; indexField < processStructure.getFieldList()
                .size(); indexField++) {
            final BlancoCsvFieldStructure field = (BlancoCsvFieldStructure) processStructure
                    .getFieldList().get(indexField);

            boolean isQuoted = false;
            String actualType = field.getType();
            if (field.getType().endsWith("(quote)")) {
                // NI[gw肪ꍇɂ́A^̂(quote)܂B
                actualType = field.getType().substring(0,
                        field.getType().length() - "(quote)".length());
                isQuoted = true;
            }
            if (field.getRequired() == false) {
                // Kvɉăbp[^ɑΉ܂B
                if (actualType.equals("int")) {
                    actualType = "java.lang.Integer";
                } else if (actualType.equals("long")) {
                    actualType = "java.lang.Long";
                }
            }

            final BlancoValueObjectFieldStructure voField = new BlancoValueObjectFieldStructure();
            voClass.getFieldList().add(voField);

            if (field.getNo() != null) {
                voField.setNo(field.getNo());
            }

            voField.setName(field.getName());
            voField.setType(actualType);

            StringBuffer strbuf = new StringBuffer();
            if (field.getNo() != null) {
                strbuf.append("ڔԍ: " + field.getNo() + "\n");
            }
            if (field.getDescription() != null) {
                strbuf.append("ڂ̐: " + field.getDescription() + "\n");
            }
            if (isQuoted) {
                strbuf.append("̓_uNI[gēo͂܂B\n");
            }

            if (field.getMinLength() != null) {
                strbuf.append("MIN: " + field.getMinLength() + "\n");
            }
            if (field.getMaxLength() != null) {
                strbuf.append("MAX: " + field.getMaxLength() + "\n");
            }
            if (field.getRequired()) {
                strbuf.append("K{\n");
            }
            voField.setDescription(strbuf.toString());

            if (field.getDefault() != null) {
                voField.setDefault(field.getDefault());
            }
        }

        final BlancoValueObjectXml2JavaClass xml2source = new BlancoValueObjectXml2JavaClass();
        xml2source.setEncoding(fEncoding);
        xml2source.structure2Source(voClass, directoryTarget);
    }
}
